==> zio-aws-docdb_2.13-5.17.104.11-sources.jar: zio/aws/docdb/model/DescribePendingMaintenanceActionsResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribePendingMaintenanceActionsResponse(
    pendingMaintenanceActions: Option[
      Iterable[zio.aws.docdb.model.ResourcePendingMaintenanceActions]
    ] = None,
    marker: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.DescribePendingMaintenanceActionsResponse = {
    import DescribePendingMaintenanceActionsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.DescribePendingMaintenanceActionsResponse
      .builder()
      .optionallyWith(
        pendingMaintenanceActions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.pendingMaintenanceActions)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.docdb.model.DescribePendingMaintenanceActionsResponse.ReadOnly =
    zio.aws.docdb.model.DescribePendingMaintenanceActionsResponse
      .wrap(buildAwsValue())
}
object DescribePendingMaintenanceActionsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.DescribePendingMaintenanceActionsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.docdb.model.DescribePendingMaintenanceActionsResponse =
      zio.aws.docdb.model.DescribePendingMaintenanceActionsResponse(
        pendingMaintenanceActions.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        marker.map(value => value)
      )
    def pendingMaintenanceActions: Option[
      List[zio.aws.docdb.model.ResourcePendingMaintenanceActions.ReadOnly]
    ]
    def marker: Option[String]
    def getPendingMaintenanceActions: ZIO[Any, AwsError, List[
      zio.aws.docdb.model.ResourcePendingMaintenanceActions.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "pendingMaintenanceActions",
      pendingMaintenanceActions
    )
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.DescribePendingMaintenanceActionsResponse
  ) extends zio.aws.docdb.model.DescribePendingMaintenanceActionsResponse.ReadOnly {
    override val pendingMaintenanceActions: Option[
      List[zio.aws.docdb.model.ResourcePendingMaintenanceActions.ReadOnly]
    ] = scala
      .Option(impl.pendingMaintenanceActions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.docdb.model.ResourcePendingMaintenanceActions.wrap(item)
        }.toList
      )
    override val marker: Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.DescribePendingMaintenanceActionsResponse
  ): zio.aws.docdb.model.DescribePendingMaintenanceActionsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-docdb_2.13-6.20.103.2-sources.jar: zio/aws/docdb/model/DescribePendingMaintenanceActionsResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribePendingMaintenanceActionsResponse(
    pendingMaintenanceActions: Optional[
      Iterable[zio.aws.docdb.model.ResourcePendingMaintenanceActions]
    ] = Optional.Absent,
    marker: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.DescribePendingMaintenanceActionsResponse = {
    import DescribePendingMaintenanceActionsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.DescribePendingMaintenanceActionsResponse
      .builder()
      .optionallyWith(
        pendingMaintenanceActions.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.pendingMaintenanceActions)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.docdb.model.DescribePendingMaintenanceActionsResponse.ReadOnly =
    zio.aws.docdb.model.DescribePendingMaintenanceActionsResponse
      .wrap(buildAwsValue())
}
object DescribePendingMaintenanceActionsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.DescribePendingMaintenanceActionsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.docdb.model.DescribePendingMaintenanceActionsResponse =
      zio.aws.docdb.model.DescribePendingMaintenanceActionsResponse(
        pendingMaintenanceActions.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        marker.map(value => value)
      )
    def pendingMaintenanceActions: Optional[
      List[zio.aws.docdb.model.ResourcePendingMaintenanceActions.ReadOnly]
    ]
    def marker: Optional[String]
    def getPendingMaintenanceActions: ZIO[Any, AwsError, List[
      zio.aws.docdb.model.ResourcePendingMaintenanceActions.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "pendingMaintenanceActions",
      pendingMaintenanceActions
    )
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.DescribePendingMaintenanceActionsResponse
  ) extends zio.aws.docdb.model.DescribePendingMaintenanceActionsResponse.ReadOnly {
    override val pendingMaintenanceActions: Optional[
      List[zio.aws.docdb.model.ResourcePendingMaintenanceActions.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.pendingMaintenanceActions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.docdb.model.ResourcePendingMaintenanceActions.wrap(item)
        }.toList
      )
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.DescribePendingMaintenanceActionsResponse
  ): zio.aws.docdb.model.DescribePendingMaintenanceActionsResponse.ReadOnly =
    new Wrapper(impl)
}
